CURRENT_NOTIFICARION_DEGREE = 'notification-manager-api.current-degree'

QUEUE_KEY = 'notification-manager-api.api-notifications.queue-key'

EMITTER_API_KEY = 'notification-manager-api.api-notifications.emitter.api-key'
EMITTER_BASE_URL = 'notification-manager-api.api-notifications.emitter.base-url'
EMITTER_TIMEOUT = 'notification-manager-api.api-notifications.emitter.timeout'

NOTIFICATION_API_KEY = 'notification-manager-api.api-notifications.emitter.notification-api-key'
